<?php
/*
Plugin Name: WP-MyPlugin
Plugin URI: http://akabeko.sakura.ne.jp/blog/
Description: My plugin.
Version: 1.0
Author: Akabeko
Author URI: http://akabeko.sakura.ne.jp/
*/

/*  Copyright 2009 Akabeko

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * プラグインの処理を行います。
 */
class WpMyPlugin
{
	/**
	 * プラグインの配置されたディレクトリを示す URL。
	 */
	private $pluginDirUrl;

	/**
	 * インスタンスを初期化します。
	 */
	public function __construct()
	{
		$this->pluginDirUrl = WP_PLUGIN_URL . '/' . array_pop( explode( DIRECTORY_SEPARATOR, dirname( __FILE__ ) ) ) . "/";

		// ハンドラの登録
		if( is_admin() )
		{
			// アクション
			add_action( "admin_head_media_upload_myplugin_form", array( &$this, "onMediaHead"      )     );
			add_action( "media_buttons",                         array( &$this, "onMediaButtons"   ), 20 );
			add_action( "media_upload_myplugin",                 "media_upload_myplugin"                 );

			// フィルタ
			add_filter( "admin_footer", array( &$this, "onAddShortCode" ) );
		}
	}

	/**
	 * ショートコードを挿入する為のスクリプトをページに埋め込みます。
	 */
	public function onAddShortCode()
	{
		// 投稿の編集画面だけを対象とする
		if( strpos( $_SERVER[ "REQUEST_URI" ], "post.php"     ) ||
			strpos( $_SERVER[ "REQUEST_URI" ], "post-new.php" ) ||
			strpos( $_SERVER[ "REQUEST_URI" ], "page-new.php" ) ||
			strpos( $_SERVER[ "REQUEST_URI" ], "page.php"     ) )
		{
			echo <<<HTML
<script type="text/javascript">
//<![CDATA
function onMyPluginShortCode( text ) { send_to_editor( text ); }
//]]>
</script>
HTML;
		}
	}

	/**
	 * メディアボタンを設定する時に発生します。
	 */
	public function onMediaButtons()
	{
		global $post_ID, $temp_ID;

		$id     = (int)( 0 == $post_ID ? $temp_ID : $post_ID );
		$iframe = apply_filters( "media_upload_myplugin_iframe_src", "media-upload.php?post_id={$id}&amp;type=myplugin&amp;tab=myplugin" );
		$option = "&amp;TB_iframe=true&amp;keepThis=true&amp;height=500&amp;width=640";
		$title  = "WP-MyPlugin";
		$button = "{$this->pluginDirUrl}images/button.png";

		echo '<a href="' . $iframe . $option . '" class="thickbox" title="' . $title . '"><img src="' . $button . '" alt="' . $title . '" /></a>';
	}

	/**
	 * メディアボタンから起動されたダイアログの内容を出力する為に発生します。
	 */
	public function onMediaButtonPage()
	{
		echo <<<HTML
<form name="url_editor">
	テキスト : <input type="text" id="myplugin_data" size="30" />
	<p>
	<input type="button" class="button-primary" value="投稿に挿入" onclick="javascript:wpMyPlugin.onClickSubmitButton()" />
	</p>
</form>
HTML;
	}

	/**
	 * メディアボタンから表示したウィンドウのヘッダが読み込まれる時に呼び出されます。
	 */
	public function onMediaHead()
	{
		echo '<script type="text/javascript" src="' . $this->pluginDirUrl . 'js/editor.js"></script>';
	}

	/**
	 * メディアボタンから表示したウィンドウのタブが設定される時に呼び出されます。
	 *
	 * @param	$tabs	規定のタブ情報コレクション。
	 *
	 * @return	実際に表示するタブ情報コレクション。
	 */
	function onModifyMediaTab( $tabs )
	{
		return array( "myplugin" => "ショートコードの編集" );
	}
}

// プラグインのインスタンス生成
if( class_exists( WpMyPlugin ) )
{
	$wpMyPlugin = new WpMyPlugin();

	// 以下の関数は管理画面限定
	if( is_admin() )
	{
		/**
		 * メディアボタンからダイアログが起動された時に呼び出されます。
		 */
		function media_upload_myplugin()
		{
			wp_iframe( "media_upload_myplugin_form" );
		}

		/**
		 * メディアボタンから起動されたダイアログの内容を出力する為に呼び出されます。
		 */
		function media_upload_myplugin_form()
		{
			global $wpMyPlugin;

			add_filter( "media_upload_tabs", array( &$wpMyPlugin, "onModifyMediaTab" ) );

			echo "<div id=\"media-upload-header\">\n";
			media_upload_header();
			echo "</div>\n";

			$wpMyPlugin->onMediaButtonPage();
		}
	}
}
?>